Now that Linux has accepted these tags, update the dtoc tool to use them.

Signed-off-by: Simon Glass <s...@chromium.org>
---

 tools/dtoc/dtb_platdata.py                     | 10 +++++-----
 tools/dtoc/test/dtoc_test_add_prop.dts         |  4 ++--
 tools/dtoc/test/dtoc_test_addr32.dts           |  4 ++--
 tools/dtoc/test/dtoc_test_addr32_64.dts        |  6 +++---
 tools/dtoc/test/dtoc_test_addr64.dts           |  6 +++---
 tools/dtoc/test/dtoc_test_addr64_32.dts        |  6 +++---
 tools/dtoc/test/dtoc_test_alias_bad.dts        |  6 +++---
 tools/dtoc/test/dtoc_test_alias_bad_path.dts   |  6 +++---
 tools/dtoc/test/dtoc_test_alias_bad_uc.dts     |  6 +++---
 tools/dtoc/test/dtoc_test_aliases.dts          |  4 ++--
 tools/dtoc/test/dtoc_test_driver_alias.dts     |  2 +-
 tools/dtoc/test/dtoc_test_inst.dts             |  6 +++---
 tools/dtoc/test/dtoc_test_invalid_driver.dts   |  2 +-
 tools/dtoc/test/dtoc_test_noparent.dts         |  6 +++---
 tools/dtoc/test/dtoc_test_noprops.dts          |  2 +-
 tools/dtoc/test/dtoc_test_phandle.dts          | 10 +++++-----
 tools/dtoc/test/dtoc_test_phandle_bad.dts      |  2 +-
 tools/dtoc/test/dtoc_test_phandle_bad2.dts     |  4 ++--
 tools/dtoc/test/dtoc_test_phandle_cd_gpios.dts | 10 +++++-----
 tools/dtoc/test/dtoc_test_phandle_reorder.dts  |  4 ++--
 tools/dtoc/test/dtoc_test_phandle_single.dts   |  4 ++--
 tools/dtoc/test/dtoc_test_simple.dts           | 10 +++++-----
 tools/dtoc/test/dtoc_test_single_reg.dts       |  4 ++--
 tools/dtoc/test_fdt.py                         |  2 +-
 24 files changed, 63 insertions(+), 63 deletions(-)

diff --git a/tools/dtoc/test/dtoc_test_add_prop.dts 
b/tools/dtoc/test/dtoc_test_add_prop.dts
index fa296e55527..8225de36d27 100644
--- a/tools/dtoc/test/dtoc_test_add_prop.dts
+++ b/tools/dtoc/test/dtoc_test_add_prop.dts
@@ -11,13 +11,13 @@
        #address-cells = <1>;
        #size-cells = <1>;
        spl-test {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,spl-test";
                intval = <1>;
        };
 
        spl-test2 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,spl-test";
                intarray = <5>;
        };
diff --git a/tools/dtoc/test/dtoc_test_addr32.dts 
b/tools/dtoc/test/dtoc_test_addr32.dts
index 239045497c6..3e7dc567292 100644
--- a/tools/dtoc/test/dtoc_test_addr32.dts
+++ b/tools/dtoc/test/dtoc_test_addr32.dts
@@ -12,13 +12,13 @@
        #size-cells = <1>;
 
        test1 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "test1";
                reg = <0x1234 0x5678>;
        };
 
        test2 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "test2";
                reg = <0x12345678 0x98765432 2 3>;
        };
diff --git a/tools/dtoc/test/dtoc_test_addr32_64.dts 
b/tools/dtoc/test/dtoc_test_addr32_64.dts
index 7599d5b0a59..7ce16feef1a 100644
--- a/tools/dtoc/test/dtoc_test_addr32_64.dts
+++ b/tools/dtoc/test/dtoc_test_addr32_64.dts
@@ -12,19 +12,19 @@
        #size-cells = <2>;
 
        test1 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "test1";
                reg = <0x1234 0x5678 0x0>;
        };
 
        test2 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "test2";
                reg = <0x12345678 0x98765432 0x10987654>;
        };
 
        test3 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "test3";
                reg = <0x12345678 0x98765432 0x10987654 2 0 3>;
        };
diff --git a/tools/dtoc/test/dtoc_test_addr64.dts 
b/tools/dtoc/test/dtoc_test_addr64.dts
index 263d2513869..5f8c23f04b8 100644
--- a/tools/dtoc/test/dtoc_test_addr64.dts
+++ b/tools/dtoc/test/dtoc_test_addr64.dts
@@ -12,19 +12,19 @@
        #size-cells = <2>;
 
        test1 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "test1";
                reg = /bits/ 64 <0x1234 0x5678>;
        };
 
        test2 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "test2";
                reg = /bits/ 64 <0x1234567890123456 0x9876543210987654>;
        };
 
        test3 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "test3";
                reg = /bits/ 64 <0x1234567890123456 0x9876543210987654 2 3>;
        };
diff --git a/tools/dtoc/test/dtoc_test_addr64_32.dts 
b/tools/dtoc/test/dtoc_test_addr64_32.dts
index 85e4f5fdaeb..bfbfd87b8de 100644
--- a/tools/dtoc/test/dtoc_test_addr64_32.dts
+++ b/tools/dtoc/test/dtoc_test_addr64_32.dts
@@ -12,19 +12,19 @@
        #size-cells = <1>;
 
        test1 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "test1";
                reg = <0x1234 0x0 0x5678>;
        };
 
        test2 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "test2";
                reg = <0x12345678 0x90123456 0x98765432>;
        };
 
        test3 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "test3";
                reg = <0x12345678 0x90123456 0x98765432 0 2 3>;
        };
diff --git a/tools/dtoc/test/dtoc_test_alias_bad.dts 
b/tools/dtoc/test/dtoc_test_alias_bad.dts
index d4f502ad0aa..69761f91146 100644
--- a/tools/dtoc/test/dtoc_test_alias_bad.dts
+++ b/tools/dtoc/test/dtoc_test_alias_bad.dts
@@ -18,20 +18,20 @@
        };
 
        spl-test {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,spl-test";
                boolval;
                intval = <1>;
        };
 
        i2c: i2c {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,i2c";
                intval = <3>;
        };
 
        spl-test3 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,spl-test";
                stringarray = "one";
                longbytearray = [09 0a 0b 0c 0d 0e 0f 10];
diff --git a/tools/dtoc/test/dtoc_test_alias_bad_path.dts 
b/tools/dtoc/test/dtoc_test_alias_bad_path.dts
index 0beca4f0d03..6f566fe4abf 100644
--- a/tools/dtoc/test/dtoc_test_alias_bad_path.dts
+++ b/tools/dtoc/test/dtoc_test_alias_bad_path.dts
@@ -18,20 +18,20 @@
        };
 
        spl-test {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,spl-test";
                boolval;
                intval = <1>;
        };
 
        i2c: i2c {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,i2c";
                intval = <3>;
        };
 
        spl-test3 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,spl-test";
                stringarray = "one";
                longbytearray = [09 0a 0b 0c 0d 0e 0f 10];
diff --git a/tools/dtoc/test/dtoc_test_alias_bad_uc.dts 
b/tools/dtoc/test/dtoc_test_alias_bad_uc.dts
index ae64f5b3b29..5d23c63a630 100644
--- a/tools/dtoc/test/dtoc_test_alias_bad_uc.dts
+++ b/tools/dtoc/test/dtoc_test_alias_bad_uc.dts
@@ -18,20 +18,20 @@
        };
 
        spl-test {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,spl-test";
                boolval;
                intval = <1>;
        };
 
        i2c: i2c {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,i2c";
                intval = <3>;
        };
 
        spl-test3 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,spl-test";
                stringarray = "one";
                longbytearray = [09 0a 0b 0c 0d 0e 0f 10];
diff --git a/tools/dtoc/test/dtoc_test_aliases.dts 
b/tools/dtoc/test/dtoc_test_aliases.dts
index ae337168632..018b834046e 100644
--- a/tools/dtoc/test/dtoc_test_aliases.dts
+++ b/tools/dtoc/test/dtoc_test_aliases.dts
@@ -9,13 +9,13 @@
 
 / {
        spl-test {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "compat1", "compat2.1-fred", "compat3";
                intval = <1>;
        };
 
        spl-test2 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "compat1", "simple_bus";
                intval = <1>;
        };
diff --git a/tools/dtoc/test/dtoc_test_driver_alias.dts 
b/tools/dtoc/test/dtoc_test_driver_alias.dts
index da7973b2e50..22369a44069 100644
--- a/tools/dtoc/test/dtoc_test_driver_alias.dts
+++ b/tools/dtoc/test/dtoc_test_driver_alias.dts
@@ -9,7 +9,7 @@
 
 / {
        gpio_a: gpios@0 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                gpio-controller;
                compatible = "sandbox_gpio_alias";
                #gpio-cells = <1>;
diff --git a/tools/dtoc/test/dtoc_test_inst.dts 
b/tools/dtoc/test/dtoc_test_inst.dts
index b8177fcef5f..9689be391bd 100644
--- a/tools/dtoc/test/dtoc_test_inst.dts
+++ b/tools/dtoc/test/dtoc_test_inst.dts
@@ -18,20 +18,20 @@
        };
 
        spl-test {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,spl-test";
                boolval;
                intval = <1>;
        };
 
        i2c: i2c {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,i2c";
                intval = <3>;
        };
 
        spl-test3 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,spl-test";
                stringarray = "one";
                longbytearray = [09 0a 0b 0c 0d 0e 0f 10];
diff --git a/tools/dtoc/test/dtoc_test_invalid_driver.dts 
b/tools/dtoc/test/dtoc_test_invalid_driver.dts
index 914ac3e899f..042a325913e 100644
--- a/tools/dtoc/test/dtoc_test_invalid_driver.dts
+++ b/tools/dtoc/test/dtoc_test_invalid_driver.dts
@@ -9,7 +9,7 @@
 
 / {
        spl-test {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "invalid";
        };
 };
diff --git a/tools/dtoc/test/dtoc_test_noparent.dts 
b/tools/dtoc/test/dtoc_test_noparent.dts
index e976dd2b8af..0efb17e0cbc 100644
--- a/tools/dtoc/test/dtoc_test_noparent.dts
+++ b/tools/dtoc/test/dtoc_test_noparent.dts
@@ -12,18 +12,18 @@
        #size-cells = <1>;
        i2c@0 {
                compatible = "sandbox,i2c";
-               u-boot,dm-tpl;
+               bootph-pre-sram;
                #address-cells = <1>;
                #size-cells = <0>;
                spl-test {
-                       u-boot,dm-pre-reloc;
+                       bootph-all;
                        compatible = "sandbox,spl-test";
                        #address-cells = <1>;
                        #size-cells = <0>;
                        status = "disabled";
                        pmic@9 {
                                compatible = "sandbox,pmic";
-                               u-boot,dm-pre-reloc;
+                               bootph-all;
                                reg = <9>;
                                low-power;
                        };
diff --git a/tools/dtoc/test/dtoc_test_noprops.dts 
b/tools/dtoc/test/dtoc_test_noprops.dts
index e6fdd11b83d..75296beb319 100644
--- a/tools/dtoc/test/dtoc_test_noprops.dts
+++ b/tools/dtoc/test/dtoc_test_noprops.dts
@@ -13,7 +13,7 @@
        i2c@0 {
                pmic@9 {
                        compatible = "sandbox,pmic";
-                       u-boot,dm-pre-reloc;
+                       bootph-all;
                        reg = <9>;
                        low-power;
                };
diff --git a/tools/dtoc/test/dtoc_test_phandle.dts 
b/tools/dtoc/test/dtoc_test_phandle.dts
index d9aa433503d..74a146b9a3e 100644
--- a/tools/dtoc/test/dtoc_test_phandle.dts
+++ b/tools/dtoc/test/dtoc_test_phandle.dts
@@ -9,34 +9,34 @@
 
 / {
        phandle: phandle-target {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "target";
                intval = <0>;
                 #clock-cells = <0>;
        };
 
        phandle_1: phandle2-target {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "target";
                intval = <1>;
                #clock-cells = <1>;
        };
        phandle_2: phandle3-target {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "target";
                intval = <2>;
                #clock-cells = <2>;
        };
 
        phandle-source {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "source";
                clocks = <&phandle &phandle_1 11 &phandle_2 12 13 &phandle>;
                phandle-name-offset = <&phandle_2>, "fred", <123>;
        };
 
        phandle-source2 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "source";
                clocks = <&phandle>;
        };
diff --git a/tools/dtoc/test/dtoc_test_phandle_bad.dts 
b/tools/dtoc/test/dtoc_test_phandle_bad.dts
index a3ddc595851..94cfada95bb 100644
--- a/tools/dtoc/test/dtoc_test_phandle_bad.dts
+++ b/tools/dtoc/test/dtoc_test_phandle_bad.dts
@@ -9,7 +9,7 @@
 
 / {
        phandle-source {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "source";
                clocks = <20>;    /* Invalid phandle */
        };
diff --git a/tools/dtoc/test/dtoc_test_phandle_bad2.dts 
b/tools/dtoc/test/dtoc_test_phandle_bad2.dts
index fe25f565fbb..4d24b96ce68 100644
--- a/tools/dtoc/test/dtoc_test_phandle_bad2.dts
+++ b/tools/dtoc/test/dtoc_test_phandle_bad2.dts
@@ -9,13 +9,13 @@
 
 / {
        phandle: phandle-target {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "target";
                intval = <0>;
        };
 
        phandle-source2 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "source";
                clocks = <&phandle>;
        };
diff --git a/tools/dtoc/test/dtoc_test_phandle_cd_gpios.dts 
b/tools/dtoc/test/dtoc_test_phandle_cd_gpios.dts
index 241743e73ec..6ad80062666 100644
--- a/tools/dtoc/test/dtoc_test_phandle_cd_gpios.dts
+++ b/tools/dtoc/test/dtoc_test_phandle_cd_gpios.dts
@@ -9,33 +9,33 @@
 
 / {
        phandle: phandle-target {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "target";
                intval = <0>;
                #gpio-cells = <0>;
        };
 
        phandle_1: phandle2-target {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "target";
                intval = <1>;
                #gpio-cells = <1>;
        };
        phandle_2: phandle3-target {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "target";
                intval = <2>;
                #gpio-cells = <2>;
        };
 
        phandle-source {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "source";
                cd-gpios = <&phandle &phandle_1 11 &phandle_2 12 13 &phandle>;
        };
 
        phandle-source2 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "source";
                cd-gpios = <&phandle>;
        };
diff --git a/tools/dtoc/test/dtoc_test_phandle_reorder.dts 
b/tools/dtoc/test/dtoc_test_phandle_reorder.dts
index aa71d56f27c..573a4f63965 100644
--- a/tools/dtoc/test/dtoc_test_phandle_reorder.dts
+++ b/tools/dtoc/test/dtoc_test_phandle_reorder.dts
@@ -10,13 +10,13 @@
 / {
 
        phandle-source2 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "source";
                clocks = <&phandle>;
        };
 
        phandle: phandle-target {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "target";
                #clock-cells = <0>;
        };
diff --git a/tools/dtoc/test/dtoc_test_phandle_single.dts 
b/tools/dtoc/test/dtoc_test_phandle_single.dts
index aacd0b15fa1..1b1763932c7 100644
--- a/tools/dtoc/test/dtoc_test_phandle_single.dts
+++ b/tools/dtoc/test/dtoc_test_phandle_single.dts
@@ -9,14 +9,14 @@
 
 / {
        phandle: phandle-target {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "target";
                intval = <0>;
                #clock-cells = <0>;
        };
 
        phandle-source2 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "source";
                clocks = <&phandle>;
        };
diff --git a/tools/dtoc/test/dtoc_test_simple.dts 
b/tools/dtoc/test/dtoc_test_simple.dts
index aef07efeaeb..08f667ee5a1 100644
--- a/tools/dtoc/test/dtoc_test_simple.dts
+++ b/tools/dtoc/test/dtoc_test_simple.dts
@@ -11,7 +11,7 @@
        #address-cells = <1>;
        #size-cells = <1>;
        spl-test {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,spl-test";
                boolval;
                maybe-empty-int = <>;
@@ -27,7 +27,7 @@
        };
 
        spl-test2 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,spl-test";
                intval = <3>;
                intarray = <5>;
@@ -40,7 +40,7 @@
        };
 
        spl-test3 {
-               u-boot,dm-pre-reloc;
+               bootph-all;
                compatible = "sandbox,spl-test";
                stringarray = "one";
                longbytearray = [09 0a 0b 0c 0d 0e 0f 10];
@@ -49,12 +49,12 @@
 
        i2c@0 {
                compatible = "sandbox,i2c";
-               u-boot,dm-pre-reloc;
+               bootph-all;
                #address-cells = <1>;
                #size-cells = <0>;
                pmic@9 {
                        compatible = "sandbox,pmic";
-                       u-boot,dm-pre-reloc;
+                       bootph-all;
                        reg = <9>;
                        low-power;
                };
diff --git a/tools/dtoc/test/dtoc_test_single_reg.dts 
b/tools/dtoc/test/dtoc_test_single_reg.dts
index 804b67855be..035937cfbfa 100644
--- a/tools/dtoc/test/dtoc_test_single_reg.dts
+++ b/tools/dtoc/test/dtoc_test_single_reg.dts
@@ -13,12 +13,12 @@
 
        i2c@0 {
                compatible = "sandbox,i2c";
-               u-boot,dm-pre-reloc;
+               bootph-all;
                #address-cells = <1>;
                #size-cells = <0>;
                pmic@9 {
                        compatible = "sandbox,pmic";
-                       u-boot,dm-pre-reloc;
+                       bootph-all;
                        reg = <9>;
                        low-power;
 
diff --git a/tools/dtoc/test_fdt.py b/tools/dtoc/test_fdt.py
index 3b8ee00d4e0..1c33b888830 100755
--- a/tools/dtoc/test_fdt.py
+++ b/tools/dtoc/test_fdt.py
@@ -135,7 +135,7 @@ class TestFdt(unittest.TestCase):
         self.assertEqual(['boolval', 'bytearray', 'byteval', 'compatible',
                           'int64val', 'intarray', 'intval', 'longbytearray',
                           'maybe-empty-int', 'notstring', 'stringarray',
-                          'stringval', 'u-boot,dm-pre-reloc'],
+                          'stringval', 'bootph-all'],
                          sorted(props.keys()))
 
     def test_check_error(self):
diff --git a/tools/dtoc/dtb_platdata.py b/tools/dtoc/dtb_platdata.py
index a69a7889ce1..39f416cfd80 100644
--- a/tools/dtoc/dtb_platdata.py
+++ b/tools/dtoc/dtb_platdata.py
@@ -35,9 +35,9 @@ PROP_IGNORE_LIST = [
     'linux,phandle',
     "status",
     'phandle',
-    'u-boot,dm-pre-reloc',
-    'u-boot,dm-tpl',
-    'u-boot,dm-spl',
+    'bootph-all',
+    'bootph-pre-sram',
+    'bootph-pre-ram',
 ]
 
 # C type declarations for the types we support
@@ -442,7 +442,7 @@ class DtbPlatdata():
         """
         parent = node.parent
         if parent and not parent.props:
-            raise ValueError("Parent node '%s' has no properties - do you need 
u-boot,dm-spl or similar?" %
+            raise ValueError("Parent node '%s' has no properties - do you need 
bootph-pre-ram or similar?" %
                              parent.path)
         num_addr, num_size = 2, 2
         if parent:
@@ -754,7 +754,7 @@ class DtbPlatdata():
                 # This might indicate that the parent node is not in the
                 # SPL/TPL devicetree but the child is. For example if we are
                 # dealing with of-platdata in TPL, the parent has a
                 # u-boot,dm-tpl tag but the child has u-boot,dm-pre-reloc. In
                 # this case the child node exists in TPL but the parent does
                 # not.
                 raise ValueError("Node '%s' requires parent node '%s' but it 
@@ -754,7 +754,7 @@ class DtbPlatdata():
                 # SPL/TPL devicetree but the child is. For example if we are
                 # dealing with of-platdata in TPL, the parent has a
-                # u-boot,dm-tpl tag but the child has u-boot,dm-pre-reloc. In
+                # bootph-pre-sram tag but the child has bootph-all. In
                 # this case the child node exists in TPL but the parent does
                 # not.
is not in the valid list" %
-- 
2.39.0.246.g2a6d74b583-goog

Reply via email to